from django.db import models
from six import python_2_unicode_compatible
from cms.models.pluginmodel import CMSPlugin
from django.utils.text import Truncator
from django.utils.html import strip_tags


@python_2_unicode_compatible
class RawHTMLPluginData(CMSPlugin):
    """
    Model for Raw HTML Plugin
    
    body - contains the HTML source text
    label - used for display purposes on the admin site
    """

    label = models.CharField(max_length=40, default="")
    body = models.TextField('HTML')

    def __str__(self):
        return Truncator(strip_tags(self.label).replace('&shy;', '')).words(5, truncate="...")
    def __unicode__(self):
        return Truncator(strip_tags(self.label).replace('&shy;', '')).words(5, truncate="...")



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import ugettext as _
from djangocms_rawhtml.models import RawHTMLPluginData


@plugin_pool.register_plugin
class RawHTMLPluginPublisher(CMSPluginBase):
    """
    Plugin to manage raw HTML text that needs to be managed from the admin interface.
    """
    name = _("Raw HTML")
    model = RawHTMLPluginData
    change_form_template = "admin/djangocms_rawhtml/change_form.html"
    render_template = "djangocms_rawhtml/plugins/raw.html"
    allow_children = False
    
    def render(self, context, instance, placeholder):
        context.update({ 'instance': instance })
        return context



# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2017-04-29 15:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='RawHTMLPluginData',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_rawhtml_rawhtmlplugindata', serialize=False, to='cms.CMSPlugin')),
                ('body', models.TextField(verbose_name=b'HTML')),
                ('label', models.CharField(default=b'', max_length=40)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

INSTALL_REQUIRES = [
    'django-cms>=3.3.0',
    'six>=1.15.0'
]

setup(
    name='djangocms-rawhtml',
    version='1.0',
    packages=[
        'djangocms_rawhtml',
        'djangocms_rawhtml.migrations',
    ],
    include_package_data=True,
    license='BSD License',
    description='Raw HTML Plugin for DjangoCMS with HTML code editor.',
    long_description=README,
    long_description_content_type="text/markdown",
    url='https://github.com/ketaro/djangocms-rawhtml',
    author='Nick Avgerinos',
    author_email='nicka@axcella.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
